@@ -18,6 +18,10 @@ class MyModel(models.Model):
         SALTY = 4
         UMAMI = 5
 
+    class ZeroEnum(Enum):
+        ZERO = 0
+        ONE = 1
+
     taste = EnumField(Taste, default=Taste.SWEET)
     taste_null_default = EnumField(Taste, null=True, blank=True, default=None)
     taste_int = EnumIntegerField(Taste, default=Taste.SWEET)
@@ -25,4 +29,6 @@ class MyModel(models.Model):
     default_none = EnumIntegerField(Taste, default=None, null=True, blank=True)
     nullable = EnumIntegerField(Taste, null=True, blank=True)
 
-    random_code = models.TextField(null=True, blank=True)
\ No newline at end of file
+    random_code = models.TextField(null=True, blank=True)
+
+    zero_field = EnumIntegerField(ZeroEnum, null=True, default=None, blank=True)
